@@ -252,7 +252,7 @@
 	  (begin
 	    (anthy-begin-input ac)
 	    (im-update-mode id 1)
-	    (anthy-update-prop-label ac))
+	    (anthy-update-prop-label ac id))
 	  (im-commit-raw (context-id c))))))
 
 (define anthy-make-index-list-rec
@@ -270,6 +270,20 @@
 		(anthy-make-index-list-rec (- n
 					      (length old-lst)))))))
 
+(define anthy-append-string
+  (lambda (ac str)
+    (and
+     str
+     (if (not (string? (car str)))
+	 (begin
+	   (anthy-append-string ac (car str))
+	   (anthy-append-string ac (cdr str))
+	   #f)
+	 #t)
+     (anthy-context-set-left-string!
+      ac (cons str (anthy-context-left-string ac))))))
+    
+
 (define anthy-begin-conv
   (lambda (ac)
     (let* ((ac-id (anthy-context-ac-id ac))
@@ -277,10 +291,9 @@
 	   (last "")
 	   (res))
       ;; get resudiual 'n'
-      (set! res (rk-push-key-last! rkc))
+       (set! res (rk-push-key-last! rkc))
       (if res
-	  (anthy-context-set-left-string!
-	   ac (cons res (anthy-context-left-string ac))))
+	  (anthy-append-string ac res))
       ;;
       (anthy-lib-set-string
        ac-id
@@ -307,7 +320,7 @@
 	     (anthy-flush ac)
 	     (anthy-context-set-on! ac #f)
 	     (im-update-mode id 0)
-	     (anthy-update-prop-label ac)
+	     (anthy-update-prop-label ac id)
 	     #f)
 	   #t)
        (if (anthy-backspace-key key key-state)
@@ -338,9 +351,7 @@
 	   (let ((res))
 	     (set! res (rk-push-key! rkc key-str))
 	     (if res
-		 (anthy-context-set-left-string!
-		  ac
-		  (cons res (anthy-context-left-string ac))))
+		 (anthy-append-string ac res))
 	     #f)
 	   #t)
        (im-commit-raw id)))))
@@ -422,9 +433,7 @@
 		     ((c (car (anthy-context-right-string ac))))
 		   (anthy-context-set-right-string!
 		    ac (cdr (anthy-context-right-string ac)))
-		   (anthy-context-set-left-string! ac
-						   (cons c
-							 (anthy-context-left-string ac)))))
+		   (anthy-append-string ac c)))
 	     #f)
 	   #t)
        ;; modifiers (except shift) => ignore
@@ -439,9 +448,7 @@
 	     (key-str (charcode->string key)))
 	 (set! res (rk-push-key! rkc key-str))
 	 (if res
-	     (anthy-context-set-left-string!
-	      ac
-	      (cons res (anthy-context-left-string ac)))))))))
+	     (anthy-append-string ac res)))))))
   
 
 (define anthy-proc-input-state
@@ -708,12 +715,11 @@
 	(begin
 	  (im-update-mode id 0)
 	  (anthy-context-set-on! ac #f)))
-    (anthy-update-prop-label ac))))
+    (anthy-update-prop-label ac id))))
 
 (define anthy-update-prop-label
-  (lambda (ac)
-    (let ((id (anthy-context-ac-id ac))
-	   (str ""))
+  (lambda (ac id)
+    (let ((str ""))
       (set! str
 	    (if (anthy-context-on ac)
 		"\tҤ餬\n"
