@@ -58,7 +58,7 @@
      (generic-prev-candidate-key key key-state)
      (= (to-lower-char key) 120))))
 
-(define skk-kana-toggle
+(define skk-kana-toggle-key
   (lambda (key key-state)
     (= (to-lower-char key) 113)))
 (define skk-cancel-key
@@ -451,7 +451,7 @@
 	   (skk-context-set-latin-conv! sc #f)
 	   #f)
 	 #t)
-     (if (skk-kana-toggle key key-state)
+     (if (skk-kana-toggle-key key key-state)
 	 (begin 
 	   (skk-context-kana-toggle sc)
 	   (skk-update-mode id sc)
@@ -541,13 +541,6 @@
 	   (stat (skk-context-state sc))
 	   (res))
       (and
-       (if (skk-kana-toggle key key-state)
-	   (begin 
-	     (skk-context-kana-toggle sc)
-	     (skk-update-mode id sc)
-	     (skk-update-prop-label sc id)
-	     #f)
-	   #t)
        (if (skk-begin-conv-key key key-state)
 	   (begin
 	     (skk-begin-conversion sc id)
@@ -600,6 +593,16 @@
 		   (skk-append-string sc p)))
 	     #f)
 	   #t)
+       (if (skk-kana-toggle-key key key-state)
+	   (begin
+            (skk-commit sc id (skk-make-string
+                               (skk-context-head sc)
+			       (not (skk-context-kana-mode sc))))
+            (skk-flush sc)
+            (skk-context-set-state! sc 'skk-state-direct)
+            (skk-update-mode id sc)
+            #f)
+          #t)
        (begin
 	 (set! key (to-lower-char key))  
 	 (set! stat (skk-context-state sc))
