@@ -114,7 +114,6 @@ long old_heap_used;
 long gc_status_flag = 1;
 char *init_file = (char *) NULL;
 char *tkbuffer = NULL;
-long gc_kind_copying = 0;
 long gc_cells_allocated = 0;
 double gc_time_taken;
 LISP *stack_start_ptr = NULL;
@@ -217,9 +216,6 @@ process_cla (int argc, char **argv, int warnflag)
 	case 'n':
 	  inums_dim = atol (&(argv[k][2]));
 	  break;
-	case 'g':
-	  gc_kind_copying = atol (&(argv[k][2]));
-	  break;
 	case 's':
 	  stack_size = atol (&(argv[k][2]));
 	  break;
@@ -250,11 +246,10 @@ print_hs_1 (void)
 {
   if (siod_verbose_level >= 2)
     {
-      fprintf (siod_output, "%ld heaps. size = %ld cells, %ld bytes. %ld inums. GC is %s\n",
+      fprintf (siod_output, "%ld heaps. size = %ld cells, %ld bytes. %ld inums.\n",
 	       nheaps,
 	       heap_size, heap_size * sizeof (struct obj),
-	       inums_dim,
-	       (gc_kind_copying == 1) ? "stop and copy" : "mark and sweep");
+	       inums_dim);
       fflush (siod_output);
     }
 }
@@ -264,10 +259,7 @@ print_hs_2 (void)
 {
   if (siod_verbose_level >= 2)
     {
-      if (gc_kind_copying == 1)
-	fprintf (siod_output, "heaps[0] at %p, heaps[1] at %p\n", heaps[0], heaps[1]);
-      else
-	fprintf (siod_output, "heaps[0] at %p\n", heaps[0]);
+      fprintf (siod_output, "heaps[0] at %p\n", heaps[0]);
       fflush (siod_output);
     }
 }
@@ -530,18 +522,6 @@ repl (struct repl_hooks *h)
   double rt, ct;
   while (1)
     {
-      if ((gc_kind_copying == 1) && ((gc_status_flag) || heap >= heap_end))
-	{
-	  rt = myruntime ();
-	  gc_stop_and_copy ();
-	  if (siod_verbose_level >= 2)
-	    {
-	      sprintf (tkbuffer,
-		       "GC took %g seconds, %ld compressed to %d, %d free\n",
-		       myruntime () - rt, old_heap_used, (int)(heap - heap_org), (int)(heap_end - heap));
-	      grepl_puts (tkbuffer, h->repl_puts);
-	    }
-	}
       if (siod_verbose_level >= 2)
 	grepl_puts ("> ", h->repl_puts);
       if (h->repl_read == NULL)
@@ -553,30 +533,20 @@ repl (struct repl_hooks *h)
 
       rt = myruntime ();
       ct = myrealtime ();
-      if (gc_kind_copying == 1)
-	cw = heap;
-      else
-	{
-	  gc_cells_allocated = 0;
-	  gc_time_taken = 0.0;
-	}
+
+      gc_cells_allocated = 0;
+      gc_time_taken = 0.0;
       if (h->repl_eval == NULL)
 	repl_return_val = x = leval (x, NIL);
       else
 	repl_return_val = x = (*h->repl_eval) (x);
-      if (gc_kind_copying == 1)
-	sprintf (tkbuffer,
-		 "Evaluation took %g seconds %d cons work, %g real.\n",
-		 myruntime () - rt,
-		 (int)(heap - cw),
-		 myrealtime () - ct);
-      else
-	sprintf (tkbuffer,
-	  "Evaluation took %g seconds (%g in gc) %ld cons work, %g real.\n",
-		 myruntime () - rt,
-		 gc_time_taken,
-		 gc_cells_allocated,
-		 myrealtime () - ct);
+
+      sprintf (tkbuffer,
+	       "Evaluation took %g seconds (%g in gc) %ld cons work, %g real.\n",
+	       myruntime () - rt,
+	       gc_time_taken,
+	       gc_cells_allocated,
+	       myrealtime () - ct);
       if (siod_verbose_level >= 3)
 	grepl_puts (tkbuffer, h->repl_puts);
       if (h->repl_print == NULL)
@@ -1238,13 +1208,12 @@ scan_registers (void)
 void
 init_storage (void)
 {
-  long j;
   LISP stack_start;
   if (stack_start_ptr == NULL)
     stack_start_ptr = &stack_start;
   init_storage_1 ();
   init_storage_a ();
-  set_gc_hooks (tc_c_file, 0, 0, 0, file_gc_free, &j);
+  set_gc_hooks (tc_c_file, 0, 0, 0, file_gc_free);
   set_print_hooks (tc_c_file, file_prin1);
 }
 
@@ -1254,7 +1223,7 @@ init_storage_1 (void)
   LISP ptr;
   long j;
   tkbuffer = (char *) must_malloc (TKBUFFERN + 1);
-  if (((gc_kind_copying == 1) && (nheaps != 2)) || (nheaps < 1))
+  if ((nheaps < 1))
     my_err ("invalid number of heaps", NIL);
   heaps = (LISP *) must_malloc (sizeof (LISP) * nheaps);
   for (j = 0; j < nheaps; ++j)
@@ -1263,10 +1232,7 @@ init_storage_1 (void)
   heap = heaps[0];
   heap_org = heap;
   heap_end = heap + heap_size;
-  if (gc_kind_copying == 1)
-    heaps[1] = (LISP) must_malloc (sizeof (struct obj) * heap_size);
-  else
-    freelist = NIL;
+  freelist = NIL;
   gc_protect (&oblistvar);
   if (obarray_dim > 1)
     {
@@ -1426,8 +1392,7 @@ set_gc_hooks (long type,
 	      LISP (*rel) (LISP),
 	      LISP (*mark) (LISP),
 	      void (*scan) (LISP),
-	      void (*free) (LISP),
-	      long *kind)
+	      void (*free) (LISP))
 {
   struct user_type_hooks *p;
   p = get_user_type_hooks (type);
@@ -1435,7 +1400,6 @@ set_gc_hooks (long type,
   p->gc_scan = scan;
   p->gc_mark = mark;
   p->gc_free = free;
-  *kind = gc_kind_copying;
 }
 
 LISP
@@ -1593,7 +1557,6 @@ allocate_aheap (void)
 {
   long j, flag;
   LISP ptr, end, next;
-  gc_kind_check ();
   for (j = 0; j < nheaps; ++j)
     if (!heaps[j])
       {
@@ -1852,19 +1815,10 @@ gc_sweep (void)
   freelist = nfreelist;
 }
 
-void
-gc_kind_check (void)
-{
-  if (gc_kind_copying == 1)
-    my_err ("cannot perform operation with stop-and-copy GC mode. Use -g0\n",
-	 NIL);
-}
-
 LISP
 user_gc (LISP args)
 {
   long old_status_flag, flag;
-  gc_kind_check ();
   flag = no_interrupt (1);
   errjmp_ok = 0;
   old_status_flag = gc_status_flag;
@@ -1912,31 +1866,19 @@ gc_status (LISP args)
       else
 	gc_status_flag = 1;
     }
-  
-  if (gc_kind_copying == 1)
-    {
-      if (gc_status_flag)
-	put_st ("garbage collection is on\n");
-      else
-	put_st ("garbage collection is off\n");
-      sprintf (tkbuffer, "%d allocated %d free\n",
-	       (int)(heap - heap_org), (int)(heap_end - heap));
-      put_st (tkbuffer);
-    }
+
+  if (gc_status_flag)
+    put_st ("garbage collection verbose\n");
   else
-    {
-      if (gc_status_flag)
-	put_st ("garbage collection verbose\n");
-      else
-	put_st ("garbage collection silent\n");
-      {
-	m = nactive_heaps ();
-	n = freelist_length ();
-	sprintf (tkbuffer, "%ld/%ld heaps, %ld allocated %ld free\n",
-		 m, nheaps, m * heap_size - n, n);
-	put_st (tkbuffer);
-      }
-    }
+    put_st ("garbage collection silent\n");
+  {
+    m = nactive_heaps ();
+    n = freelist_length ();
+    sprintf (tkbuffer, "%ld/%ld heaps, %ld allocated %ld free\n",
+	     m, nheaps, m * heap_size - n, n);
+    put_st (tkbuffer);
+  }
+
   return (NIL);
 }
 
@@ -1946,7 +1888,7 @@ gc_info (LISP arg)
   switch (get_c_long (arg))
     {
     case 0:
-      return ((gc_kind_copying == 1) ? sym_t : NIL);
+      return NIL;
     case 1:
       return (flocons (nactive_heaps ()));
     case 2:
@@ -1954,9 +1896,7 @@ gc_info (LISP arg)
     case 3:
       return (flocons (heap_size));
     case 4:
-      return (flocons ((gc_kind_copying == 1)
-		       ? (long) (heap_end - heap)
-		       : freelist_length ()));
+      return (flocons (freelist_length ()));
     default:
       return (NIL);
     }
