@@ -32,37 +32,10 @@ init_sliba_version (void)
 	  NIL);
 }
 
-static LISP bashnum = NIL;
 static LISP sym_e = NIL;
 static LISP sym_f = NIL;
 
-void
-init_storage_a1 (long type)
-{
-  long j;
-  struct user_type_hooks *p;
-  set_gc_hooks (type,
-		array_gc_relocate,
-		array_gc_mark,
-		array_gc_scan,
-		array_gc_free,
-		&j);
-  set_print_hooks (type, array_prin1);
-  p = get_user_type_hooks (type);
-  p->equal = array_equal;
-  p->c_sxhash = array_sxhash;
-}
-
-void
-init_storage_a (void)
-{
-  gc_protect (&bashnum);
-  bashnum = newcell (tc_flonum);
-  init_storage_a1 (tc_string);
-  init_storage_a1 (tc_lisp_array);
-}
-
-LISP
+static LISP
 array_gc_relocate (LISP ptr)
 {
   LISP nw;
@@ -73,29 +46,18 @@ array_gc_relocate (LISP ptr)
   return (nw);
 }
 
-void
+static void
 array_gc_scan (LISP ptr)
 {
-  long j;
-  if TYPEP
-    (ptr, tc_lisp_array)
-      for (j = 0; j < ptr->storage_as.lisp_array.dim; ++j)
-      ptr->storage_as.lisp_array.data[j] =
-	gc_relocate (ptr->storage_as.lisp_array.data[j]);
 }
 
-LISP
+static LISP
 array_gc_mark (LISP ptr)
 {
-  long j;
-  if TYPEP
-    (ptr, tc_lisp_array)
-      for (j = 0; j < ptr->storage_as.lisp_array.dim; ++j)
-      gc_mark (ptr->storage_as.lisp_array.data[j]);
   return (NIL);
 }
 
-void
+static void
 array_gc_free (LISP ptr)
 {
   switch (ptr->type)
@@ -106,7 +68,7 @@ array_gc_free (LISP ptr)
     }
 }
 
-void
+static void
 array_prin1 (LISP ptr, struct gen_printio *f)
 {
   int j;
@@ -153,6 +115,20 @@ array_prin1 (LISP ptr, struct gen_printio *f)
     }
 }
 
+void
+init_storage_a (void)
+{
+  struct user_type_hooks *p;
+  set_gc_hooks (tc_string,
+		array_gc_relocate,
+		array_gc_mark,
+		array_gc_scan,
+		array_gc_free);
+  set_print_hooks (tc_string, array_prin1);
+  p = get_user_type_hooks (tc_string);
+  p->equal = array_equal;
+}
+
 LISP
 strcons (long length, char *data)
 {
@@ -454,61 +430,6 @@ lreadstring (struct gen_readio * f)
   return (strcons (j, tkbuffer));
 }
 
-#define HASH_COMBINE(_h1,_h2,_mod) ((((_h1) * 17 + 1) ^ (_h2)) % (_mod))
-
-long
-c_sxhash (LISP obj, long n)
-{
-  long hash;
-  unsigned char *s;
-  LISP tmp;
-  struct user_type_hooks *p;
-  STACK_CHECK (&obj);
-  INTERRUPT_CHECK ();
-  switch TYPE
-    (obj)
-    {
-    case tc_nil:
-      return (0);
-    case tc_cons:
-      hash = c_sxhash (CAR (obj), n);
-      for (tmp = CDR (obj); CONSP (tmp); tmp = CDR (tmp))
-	hash = HASH_COMBINE (hash, c_sxhash (CAR (tmp), n), n);
-      hash = HASH_COMBINE (hash, c_sxhash (tmp, n), n);
-      return (hash);
-    case tc_symbol:
-      for (hash = 0, s = (unsigned char *) PNAME (obj); *s; ++s)
-	hash = HASH_COMBINE (hash, *s, n);
-      return (hash);
-    case tc_subr_0:
-    case tc_subr_1:
-    case tc_subr_2:
-    case tc_subr_3:
-    case tc_subr_4:
-    case tc_subr_5:
-    case tc_lsubr:
-    case tc_fsubr:
-    case tc_msubr:
-      for (hash = 0, s = (unsigned char *) obj->storage_as.subr.name; *s; ++s)
-	hash = HASH_COMBINE (hash, *s, n);
-      return (hash);
-    case tc_flonum:
-      return (((unsigned long) FLONM (obj)) % n);
-    default:
-      p = get_user_type_hooks (TYPE (obj));
-      if (p->c_sxhash)
-	return ((*p->c_sxhash) (obj, n));
-      else
-	return (0);
-    }
-}
-
-LISP
-sxhash (LISP obj, LISP n)
-{
-  return (flocons (c_sxhash (obj, FLONUMP (n) ? (long) FLONM (n) : 10000)));
-}
-
 LISP
 equal (LISP a, LISP b)
 {
@@ -562,28 +483,6 @@ array_equal (LISP a, LISP b)
     }
 }
 
-long
-array_sxhash (LISP a, long n)
-{
-  long j, len, hash;
-  unsigned char *char_data;
-  unsigned long *long_data;
-  double *double_data;
-  switch (TYPE (a))
-    {
-    case tc_string:
-      len = a->storage_as.string.dim;
-      for (j = 0, hash = 0, char_data = (unsigned char *) a->storage_as.string.data;
-	   j < len;
-	   ++j, ++char_data)
-	hash = HASH_COMBINE (hash, *char_data, n);
-      return (hash);
-    default:
-      errswitch ();
-      return (0);
-    }
-}
-
 LISP
 assoc (LISP x, LISP alist)
 {
@@ -772,8 +671,6 @@ nlength (LISP obj)
     {
     case tc_string:
       return (strlen (obj->storage_as.string.data));
-    case tc_lisp_array:
-      return (obj->storage_as.lisp_array.dim);
     case tc_nil:
       return (0);
     case tc_cons:
@@ -1043,69 +940,6 @@ nth (LISP x, LISP li)
     return (my_err ("bad arg to nth", x));
 }
 
-/* these lxxx_default functions are convenient for manipulating
-   command-line argument lists */
-
-LISP
-lref_default (LISP li, LISP x, LISP fcn)
-{
-  LISP l;
-  long j, n = get_c_long (x);
-  for (j = 0, l = li; (j < n) && CONSP (l); ++j)
-    l = CDR (l);
-  if CONSP
-    (l)
-      return (CAR (l));
-  else if NNULLP
-    (fcn)
-      return (lapply (fcn, NIL));
-  else
-    return (NIL);
-}
-
-LISP
-larg_default (LISP li, LISP x, LISP dval)
-{
-  LISP l = li, elem;
-  long j = 0, n = get_c_long (x);
-  while NNULLP
-    (l)
-    {
-      elem = car (l);
-      if (TYPEP (elem, tc_string) && strchr ("-:", *get_c_string (elem)))
-	l = cdr (l);
-      else if (j == n)
-	return (elem);
-      else
-	{
-	  l = cdr (l);
-	  ++j;
-	}
-    }
-  return (dval);
-}
-
-LISP
-lkey_default (LISP li, LISP key, LISP dval)
-{
-  LISP l = li, elem;
-  char *ckey, *celem;
-  long n;
-  ckey = get_c_string (key);
-  n = strlen (ckey);
-  while NNULLP
-    (l)
-    {
-      elem = car (l);
-      if (TYPEP (elem, tc_string) && (*(celem = get_c_string (elem)) == ':') &&
-	  (strncmp (&celem[1], ckey, n) == 0) && (celem[n + 1] == '='))
-	return (strcons (strlen (&celem[n + 2]), &celem[n + 2]));
-      l = cdr (l);
-    }
-  return (dval);
-}
-
-
 LISP
 llist (LISP l)
 {
@@ -1459,8 +1293,6 @@ ltypeof (LISP obj)
       return (cintern ("tc_free_cell"));
     case tc_string:
       return (cintern ("tc_string"));
-    case tc_lisp_array:
-      return (cintern ("tc_lisp_array"));
     case tc_c_file:
       return (cintern ("tc_c_file"));
     default:
@@ -1668,7 +1500,6 @@ init_subrs_a (void)
   init_subr_1 ("string-dimension", string_dim);
   init_subr_3 ("print-to-string", print_to_string);
   init_subr_2 ("cons-array", cons_array);
-  init_subr_2 ("sxhash", sxhash);
   init_subr_2 ("equal?", equal);
   init_subr_2 ("assoc", assoc);
   init_subr_2 ("assv", assv);
@@ -1694,9 +1525,6 @@ init_subrs_a (void)
   init_subr_1 ("string?", stringp);
   gc_protect_sym (&sym_e, "e");
   gc_protect_sym (&sym_f, "f");
-  init_subr_3 ("lref-default", lref_default);
-  init_subr_3 ("larg-default", larg_default);
-  init_subr_3 ("lkey-default", lkey_default);
   init_lsubr ("list", llist);
   init_lsubr ("writes", writes);
   init_subr_3 ("qsort", lqsort);
