@@ -6,6 +6,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+ #include <sys/stat.h>
 #include <uim/uim.h>
 #include <uim/uim-helper.h>
 #include "context.h"
@@ -29,52 +30,62 @@ get_server_command(void)
 
 int uim_helper_init_client_fd(void (*disconnect_cb)(void))
 {
-    int fd;
-    struct sockaddr_un server;
-    char *path = uim_helper_get_pathname();
+  struct stat lst, fst;
+  int fd;
+  struct sockaddr_un server;
+  char *path = uim_helper_get_pathname();
+  
+  uim_fd = -1;
+  
+  if(!path)
+    return -1;
 
-    uim_fd = -1;
-
-    if(!path)
-      return -1;
-
-    memset(&server, 0, sizeof(server));
+  memset(&server, 0, sizeof(server));
+  
+  server.sun_family = PF_UNIX;
+  strcpy(server.sun_path, path);
+  free(path);
+  
+  fd = socket(PF_UNIX, SOCK_STREAM, 0);
+  if (fd < 0) {
+    perror("fail to create socket");
+    return -1;
+  }
+  
+  if (fstat(fd, &fst) != 0) {
+    close(fd);
+    return -1;
+  }  
+  if (fst.st_uid != getuid()) {
+    close(fd);
+    return -1;
+  }
+  
+  if(connect(fd,&server,sizeof(server)) == -1){
+    int serv_pid = 0;
+    FILE *serv_r = NULL, *serv_w = NULL;
+    char buf[128];
     
-    server.sun_family = PF_UNIX;
-    strcpy(server.sun_path, path);
-    free(path);
-
-    fd = socket(PF_UNIX, SOCK_STREAM, 0);
-    if (fd < 0) {
-      perror("fail to create socket");
+    serv_pid = uim_ipc_open_command(serv_pid, &serv_r, &serv_w, get_server_command());
+    
+    if(serv_pid == 0) {
       return -1;
     }
-
-    if(connect(fd,&server,sizeof(server)) == -1){
-      int serv_pid = 0;
-      FILE *serv_r = NULL, *serv_w = NULL;
-      char buf[128];
-
-      serv_pid = uim_ipc_open_command(serv_pid, &serv_r, &serv_w, get_server_command());
-
-      if(serv_pid == 0) {
-	return -1;
-      }
-
-      while (fgets (buf, sizeof(buf), serv_r ) != NULL ) {
-	if(strcmp( buf, "\n" ) == 0)
-	  break;
-      }
-
-      if(connect(fd,&server,sizeof(server)) == -1){
-	return -1;
-      }
+    
+    while (fgets (buf, sizeof(buf), serv_r ) != NULL ) {
+      if(strcmp( buf, "\n" ) == 0)
+	break;
     }
-
-    uim_disconnect_cb = disconnect_cb;
-
-    uim_fd = fd;
-    return fd;
+    
+    if(connect(fd,&server,sizeof(server)) == -1){
+      return -1;
+    }
+  }
+  
+  uim_disconnect_cb = disconnect_cb;
+  
+  uim_fd = fd;
+  return fd;
 }
 
 
