@@ -158,6 +158,98 @@ c_getenv(LISP str_)
   return strcons(strlen(val), val);
 }
 
+static char **
+uim_strsplit(char *splittee, char *splitter)
+{
+  char *cur, *tmp;
+  int nr_token = 0;
+  int in_token = 0;
+  char **res;
+  int len;
+  int i;
+
+  if(!splittee || !splitter)
+    return NULL;
+
+
+  /* count the number of token */
+  cur = splittee;
+  while (*cur) {
+    if (strchr(splitter, *cur)) {
+      in_token = 0;
+    } else {
+      if (!in_token) {
+	nr_token ++;
+      }
+      in_token = 1;
+    }
+    cur ++;
+  }
+  /* allocate buffer */
+  res = (char **)malloc(sizeof(char *) * (nr_token + 1) );
+  if (!res) {
+    return NULL;
+  }
+  /**/
+  cur = splittee;
+  for (i = 0; i < nr_token; i++) {
+    /* find current token's start */
+    while (strchr(splitter, *cur)) {
+      cur ++;
+    }
+    /* calc length */
+    len = 0;
+    tmp = cur;
+    while (!strchr(splitter, *tmp)) {
+      len ++;
+      tmp ++;
+    }
+    /* store */
+    res[i] = malloc(sizeof(char *) * (len + 1));
+    strncpy(res[i], cur, len);
+    res[i][len] = 0;
+    cur = tmp;
+  }
+  /**/
+  res[nr_token] = NULL;
+
+  return res;
+}
+
+static LISP
+uim_split_string(LISP _splittee, LISP _splitter)
+{
+  char *splittee = get_c_string(_splittee);
+  char *splitter = get_c_string(_splitter);
+  char **strs;
+  LISP l = NIL;
+  int i;
+  int j;
+
+  if(_splittee == NULL || _splitter == NULL)
+    return NIL;
+
+  if(splittee == NULL || splitter == NULL)
+    return NIL;
+
+   strs = uim_strsplit(splittee, splitter);
+
+   if(!strs || !*strs)
+     return NIL;
+
+   for(j = 0;strs[j] != '\0' ; j++){}
+
+   j--;
+   
+   for(i = j; i >= 0 ; i--)
+     {
+       l = cons ( strcons( strlen(strs[i]), strs[i] ), l );
+            free(strs[i]);
+     }
+   free(strs);
+   return l;
+}
+
 void
 uim_init_util_subrs()
 {
@@ -170,4 +262,6 @@ uim_init_util_subrs()
   init_subr_2("rk-lib-find-partial-seq", rk_find_partial_seq);
   init_subr_2("rk-lib-expect-seq", rk_expect_seq);
   init_subr_1("getenv", c_getenv);
+  init_subr_2("string-split", uim_split_string);
+
 }
