@@ -187,7 +187,7 @@ uim_set_mode_list_update_cb(uim_context uc,
 
 void
 uim_set_prop_list_update_cb(uim_context uc,
-			    void (*update_cb)(void *ptr))
+			    void (*update_cb)(void *ptr, char *str))
 {
   uc->prop_list_update_cb = update_cb;
 }
@@ -195,7 +195,7 @@ uim_set_prop_list_update_cb(uim_context uc,
 
 void
 uim_set_prop_label_update_cb(uim_context uc,
-			     void (*update_cb)(void *ptr))
+			     void (*update_cb)(void *ptr, char *str))
 {
   uc->prop_label_update_cb = update_cb;
 }
@@ -394,7 +394,6 @@ uim_init_scm()
     {
       "siod",
       "-h100000:10",
-      "-g0",
       "-o1000",
       "-s200000",
       "-n2048",
@@ -410,11 +409,11 @@ uim_init_scm()
       else
 	verbose_argv[2] = *env;
     }
-    siod_argv[6] = verbose_argv;
+    siod_argv[5] = verbose_argv;
   }
   /* init siod */
   siod_output = stderr;
-  process_cla (7, siod_argv, 1);
+  process_cla (6, siod_argv, 1);
   init_storage ();
   init_subrs ();
   set_fatal_exit_hook(exit_hook);
