@@ -7,6 +7,7 @@
 #include "xim.h"
 #include "ximserver.h"
 #include "convdisp.h"
+#include "canddisp.h"
 #include "xdispatch.h"
 
 //
@@ -127,7 +128,7 @@ private:
     int calc_ce_width(int b,int e);
 
     void validate_area();
-    
+
     char_ent *m_ce;
     int m_ce_len;
     PeOvWin *m_ov_win;
@@ -523,6 +524,7 @@ ConvdispOv::~ConvdispOv()
     }
 }
 
+
 void ConvdispOv::update_preedit()
 {
     if (!m_pe) {
@@ -538,7 +540,7 @@ void ConvdispOv::update_preedit()
     draw_preedit();
 
     if (m_atr->has_atr(ICA_FocusWindow)
-	&& m_atr->has_atr(ICA_SpotLocation)){
+        && m_atr->has_atr(ICA_SpotLocation)){
 	int x, y;
 	Window win;
 	XTranslateCoordinates(XimServer::gDpy,m_atr->focus_window,
@@ -546,20 +548,10 @@ void ConvdispOv::update_preedit()
 			      m_atr->spot_location.x,
 			      m_atr->spot_location.y,
 			      &x, &y, &win);
-	if (x + CAND_WIN_WIDTH > scr_width) {
-	    x = scr_width - CAND_WIN_WIDTH;
-	}
-	if (x < 0) {
-	    x = 0;
-	}
-	if (y + CAND_WIN_HEIGHT > scr_height) {
-	    //¦˸䥦ɥФ
-	    y -= (CAND_WIN_HEIGHT+m_atr->line_space+2);
-	}else{
-	    // ¦˸䥦ɥФ
-	    y += 2;
-	}
-    }
+        
+        Canddisp* disp = canddisp_singleton();
+        disp->move(x, y + 2);
+    }    
 }
 
 void ConvdispOv::validate_area()
@@ -618,10 +610,14 @@ void ConvdispOv::update_icxatr()
 
 void ConvdispOv::set_focus()
 {
+    Canddisp* disp = canddisp_singleton();
+    disp->show();
 }
 
 void ConvdispOv::unset_focus()
 {
+    Canddisp* disp = canddisp_singleton();
+    disp->hide();
 }
 
 void ConvdispOv::draw_preedit()
@@ -846,6 +842,20 @@ void ConvdispOs::update_preedit()
       mConn->push_passive_packet(t);
       */
       
+    if (m_atr->has_atr(ICA_FocusWindow)
+        && m_atr->has_atr(ICA_SpotLocation)){
+	int x, y;
+	Window win;
+	XTranslateCoordinates(XimServer::gDpy,m_atr->focus_window,
+			      DefaultRootWindow(XimServer::gDpy),
+			      m_atr->spot_location.x,
+			      m_atr->spot_location.y,
+			      &x, &y, &win);
+        
+        Canddisp* disp = canddisp_singleton();
+        disp->move(x, y + 2);
+    }    
+    
 }
 
 void ConvdispOs::update_icxatr()
@@ -902,10 +912,14 @@ void ConvdispOs::compose_feedback_array(TxPacket *t)
 
 void ConvdispOs::set_focus()
 {
+    Canddisp* disp = canddisp_singleton();
+    disp->show();
 }
 
 void ConvdispOs::unset_focus()
 {
+    Canddisp* disp = canddisp_singleton();
+    disp->hide();
 }
 /*
  * Local variables:
