@@ -2,13 +2,8 @@
 #ifndef _convdisp_h_included_
 #define _convdisp_h_included_
 
-// 
-#define CAND_WIN_WIDTH 300
-#define CAND_WIN_HEIGHT 300
-
-#define CAND_COUNT 12
-
 #include "ximserver.h"
+#include <vector>
 
 class icxatr;
 
