@@ -123,11 +123,17 @@ public:
     void clear_preedit();
     void pushback_preedit_string(int attr, char *str);
     void update_preedit();
+    void candidate_begin(int nr, int index);
+    void candidate_update(int index);
+    void candidate_end();
 public:
     static void commit_cb(void *, char *);
     static void clear_cb(void *);
     static void pushback_cb(void *, int attr, char *str);
     static void update_cb(void *);
+    static void candidate_begin_cb(void *ptr, int nr, int index);
+    static void candidate_update_cb(void *ptr, int index);
+    static void candidate_end_cb(void *ptr);
 protected:
     void commit_string(char *);
     XimIC *mXic;
